# bestia
bestia is a library of functions and classes designed to help you build dynamic command-line applications on Linux / Darwin systems.

***
## available functions / classes
### connect.py
* http_get

### iterate.py
* items_are_equal
* indexes_from_string
* random_unique_items_from_list
* pop_random_item
* string_to_list
* list_to_string

### misc.py
* copy_to_clipboard
* file_type
* say
* command_output
* abort

### output.py
* tty_size
* tty_rows
* tty_columns
* Row
* echo
* FString
* clear_screen
* expand_seconds
* remove_path
* replace_special_chars
* obfuscate_random_chars

***
## dependencies
Installing bestia on your system will also install the following pip libraries:

* pyperclip
* termcolor
